@@ -299,7 +299,7 @@ def _getuserbase():
     def joinuser(*args):
         return os.path.expanduser(os.path.join(*args))
 
-    if os.name == "nt" and not 'mingw' in sys.version.lower():
+    if os.name == "nt" and not sys._is_mingw:
         base = os.environ.get("APPDATA") or "~"
         return joinuser(base, _get_implementation())
 
@@ -312,7 +312,7 @@ def _getuserbase():
 # Copy of sysconfig.get_platform() but only for MinGW
 def _get_platform():
     if os.name == 'nt':
-        if 'mingw' in sys.version.lower():
+        if sys._is_mingw:
             platform = 'mingw'
             if 'amd64' in sys.version.lower():
                 platform += '_x86_64'
@@ -334,12 +334,6 @@ def _get_platform():
                 platform += "_gnu"
 
             return platform
-        if 'amd64' in sys.version.lower():
-            return 'win-amd64'
-        if '(arm)' in sys.version.lower():
-            return 'win-arm32'
-        if '(arm64)' in sys.version.lower():
-            return 'win-arm64'
     return sys.platform
 
 # Same to sysconfig.get_path('purelib', os.name+'_user')
@@ -353,8 +347,8 @@ def _get_path(userbase):
     implementation = _get_implementation()
     implementation_lower = implementation.lower()
     if os.name == 'nt':
-        if 'mingw' in sys.version.lower():
-            return f'{userbase}/lib/{implementation_lower}{version[0]}.{version[1]}-{_get_platform()}/site-packages'
+        if sys._is_mingw:
+            return f'{userbase}/lib/{implementation_lower}{version[0]}.{version[1]}-{_get_platform()}{abi_thread}/site-packages'
 
         ver_nodot = sys.winver.replace('.', '')
         return f'{userbase}\\{implementation}{ver_nodot}\\site-packages'
@@ -434,7 +428,7 @@ def getsitepackages(prefixes=None):
             abi_thread = 't'
         else:
             abi_thread = ''
-        if os.name == 'posix' or 'mingw' in sys.version.lower():
+        if os.name == 'posix' or sys._is_mingw:
             libdirs = [sys.platlibdir]
             if sys.platlibdir != "lib":
                 libdirs.append("lib")
@@ -478,9 +472,9 @@ def setcopyright():
     """Set 'copyright' and 'credits' in builtins"""
     builtins.copyright = _sitebuiltins._Printer("copyright", sys.copyright)
     builtins.credits = _sitebuiltins._Printer("credits", """\
-    Thanks to CWI, CNRI, BeOpen, Zope Corporation, the Python Software
-    Foundation, and a cast of thousands for supporting Python
-    development.  See www.python.org for more information.""")
+Thanks to CWI, CNRI, BeOpen, Zope Corporation, the Python Software
+Foundation, and a cast of thousands for supporting Python
+development.  See www.python.org for more information.""")
     files, dirs = [], []
     # Not all modules are required to have a __file__ attribute.  See
     # PEP 420 for more details.
